# DJAqua
#    description:   A plugin to announce a track's artist and title before and after play
#    author:        Richard Schwarting (aquarichy@gmail.com)
#    license:       GPL2
#    (out of) date: 2009/04/06

# Copyright (C) 2009 Richard Schwarting
#
#     This program is free software; you can redistribute it and/or modify
#     it under the terms of the GNU General Public License as published by
#     the Free Software Foundation; either version 2 of the License, or
#     (at your option) any later version.
#
#     This program is distributed in the hope that it will be useful,
#     but WITHOUT ANY WARRANTY; without even the implied warranty of
#     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#     GNU General Public License for more details.
#
#     You should have received a copy of the GNU General Public License
#     along with this program; if not, write to the Free Software
#     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import gtk
import sys
from DJSpeaker import DJSpeaker

class DJAquaConfigureDialog(gtk.Window):

    def __init__(self, djaqua):
        gtk.Window.__init__(self)
        self.set_title("DJAqua")
        self.conf = djaqua.get_conf()
        self.dj = djaqua.get_speaker()
        self.num_voices = 0

        # Dim Volume
        dim_volume_button = gtk.CheckButton("Dim volume when speaking?")
        dim_volume_button.connect("toggled", self._dim_volume_toggled_cb)
        dim_volume_button.set_active(self.conf.get_volume_dimming())

        # Output Module selection
        module_label = gtk.Label("Speech Engine:")

        # TODO: use a richer ComboBox model other than the string ListStore so I
        # can store voice information and indices better :)
        old_module = self.conf.get_output_module()
        num_module = 0

        modules_combo = gtk.combo_box_new_text()
        for module in self.dj.list_output_modules():
            modules_combo.append_text(str(module))
            if module == old_module:
                modules_combo.set_active(num_module)
            num_module += 1
        modules_combo.connect("changed", self._output_module_changed_cb)

        # Voice selection
        voices_label = gtk.Label("Voice:")

        self.voices_combo = gtk.combo_box_new_text()
        self._generate_voices_menu(old_module)
        self.voices_combo.connect("changed", self._voice_changed_cb)

        ## building vertical box of all options

        options_box = gtk.VBox()
        options_box.add(dim_volume_button);
        options_box.add(module_label);
        options_box.add(modules_combo);
        options_box.add(voices_label);
        options_box.add(self.voices_combo);
        options_box.show_all()

        self.add(options_box);

        # TODO: somehow centre the dialogue near the mouse 

    ### callbacks on our widgets
    def _dim_volume_toggled_cb(self, dim_volume_button):
        self.conf.set_volume_dimming(dim_volume_button.get_active())

    def _output_module_changed_cb(self, module_combo):
        output_module = module_combo.get_active_text()
        
        self.conf.set_output_module(output_module)
        self.dj.set_output_module(output_module)
        self._generate_voices_menu(output_module)
        self.dj.speak("Hello.") # TODO: say Hello in the appropriate language; need a translation library for this?  #LONGTERMFUTURE
        
    def _voice_changed_cb(self, voice_combo):
        if not self.mute_voice_changed_cb: # when we rebuild the list, this gets called a lot ...
            self.conf.set_voice(voice_combo.get_active_text())
            self.dj.set_voice(voice_combo.get_active_text())
            self.dj.cancel()
            self.dj.speak("Hello.") # TODO: say Hello in the appropriate language; need a translation library for this?  #LONGTERMFUTURE

    ### rebuild the voice menu for when we change output modules
    def _generate_voices_menu(self, output_module):
        self.mute_voice_changed_cb = True

        # clear any existing ones
        for i in range(0, self.num_voices):
            self.voices_combo.remove_text(0)
        self.num_voices = 0

        old_voice = self.conf.get_voice(output_module)

        for voice in self.dj.list_voices():
            #self.voices_combo.append_text("%s %s %s" % (voice[1], voice[2], voice[0]))
            self.voices_combo.append_text(voice[0])
            if voice[0] == old_voice:
                self.voices_combo.set_active(self.num_voices) # we don't know which one is currently active 
            self.num_voices += 1

        if self.voices_combo.get_active() == -1:
            self.voices_combo.set_active(0);
      

        self.voices_combo.show_all() # redraw the new widgets

        self.mute_voice_changed_cb = False

        
        
    
